# emachinery
A package for analysis of electric machinery.

## Functions

### 1. Machine Quantities Calculations & Conversion
### 2. PI Regulator Tuner based on TI InstaSPIN 
### 3. Run C-based Numerical Integration Simulation
### 4. Sweep Frequency Analysis
### 5. FEA based Machine Design and Multi-Objective Optimization (develop)
### 6. PC User GUI for Serial Communication to DSP (develop)










----
_This package is published following https://www.youtube.com/watch?v=Qs91v2Tofys_

----

